
# TODO

- configuration files
    - log location
    - enable/disable agents

- eyetracking setup
    - calibration is done in the eyetracker manager (external software)
    - a way to test that eyetracking is working correctly? 

- install and update scripts



# as part of the demo

- show how to set up schedules
- show how to set up tasks
- show how to install/update the system
    - make everything avaliable on pip, this will be by far the easiest way.

- show what happens if the eyetracking setup fails
- show what happens if the eyetracking breaks half way through
- show how to locate and interpret the log files
- show how agents can be enabled/disabled
- discuss what should be configurable for experiments
- what experiments are we now doing, I need to tailor setup files for this and write specific agent behaviours

